import {RcsbFv3DCustom, RcsbFv3DCustomInterface} from "../../RcsbFv3D/RcsbFv3DCustom";
import { DebugUtil } from "@rcsb/rcsb-molstar/build/src/tmdet-extension/debug-utils";
import { createFeatureViewerConfing } from "./FeatureViewConfig";
import { TmDetDescriptorCache } from "@rcsb/rcsb-molstar/build/src/tmdet-extension/prop";
import { registerRegionDescriptorData } from "./UniTmpHelper";

document.addEventListener("DOMContentLoaded", (event) => {
    (async function(event) {

        DebugUtil.enableLog();

        const pdbEntry = "1afo";
        const labelAsymId = "B";
        const params = {
            side1: "Inside",
            htpEntry: "GLPA_HUMAN",
            pdbEntry: pdbEntry,
            labelAsymId: labelAsymId,
            pdbtmEntry: `${pdbEntry}_${labelAsymId}`
        };

        const descriptorUrl = `/${pdbEntry}.json`;
        registerRegionDescriptorData(descriptorUrl, params.side1 as any);

        const { sequenceConfig, molstarConfig } = await createFeatureViewerConfing(params);
        const panel3dConfig: RcsbFv3DCustomInterface = {
            elementId: "null",
            sequencePanelConfig: sequenceConfig,
            structurePanelConfig: molstarConfig
        };
        DebugUtil.log('Panel config', panel3dConfig);
        const pdbtmDescriptor = TmDetDescriptorCache.get(pdbEntry);
        if (pdbtmDescriptor) {
            const mx = DebugUtil.descriptorMxToMat4(pdbtmDescriptor!.additional_entry_annotations.membrane.transformation_matrix as any);
            DebugUtil.log('Membrane transformation matrix:', mx);
            (panel3dConfig.structurePanelConfig!.loadConfig as any).loadParams.matrix = mx;
        }


        const panel3d = new RcsbFv3DCustom(panel3dConfig);
        panel3d.render();
    })();
});
